@@ -28,8 +28,11 @@
 #include "eog-image.h"
 #include "eog-util.h"
 #include "eog-thumb-view.h"
+
+#if HAVE_EXIF
 #include "eog-exif-details.h"
 #include "eog-exif-util.h"
+#endif
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -167,8 +170,11 @@ eog_xmp_set_label (XmpPtr xmp,
 	uint32_t options;
 
 	XmpStringPtr value = xmp_string_new ();
-
+#ifdef HAVE_EXEMPI_NEW_API
+	if (xmp_get_property (xmp, ns, propname, value, &options)) {
+#else
 	if (xmp_get_property_and_bits (xmp, ns, propname, value, &options)) {
+#endif
 		if (XMP_IS_PROP_SIMPLE (options)) {
 			gtk_label_set_text (GTK_LABEL (w), xmp_string_cstr (value));
 		} else if (XMP_IS_PROP_ARRAY (options)) {
